@@ -94,14 +94,10 @@ pub struct PrivateRsaKeyMaterial {
 impl From<&PrivateRsaKeyMaterial> for tss_esapi_sys::TPM2B_PRIVATE_KEY_RSA {
     fn from(private_rsa: &PrivateRsaKeyMaterial) -> Self {
         let key_prime = hex::decode(&private_rsa.prime).unwrap();
-        let mut key_prime_buffer = [0u8; 256];
-        key_prime_buffer[..key_prime.len()].clone_from_slice(&key_prime[..key_prime.len()]);
-        let key_prime_len = key_prime.len().try_into().unwrap();
-
-        Self {
-            size: key_prime_len,
-            buffer: key_prime_buffer,
-        }
+        let mut result = Self::default();
+        result.buffer[..key_prime.len()].clone_from_slice(&key_prime[..key_prime.len()]);
+        result.size = key_prime.len().try_into().unwrap();
+        result
     }
 }
 
